@@ -43,11 +43,10 @@ cor.fk <- function (x, y = NULL)
 	if (length (x) != length (y))
 		stop ("x and y must have same length.")
 
-	ret <- .C ("kendallNlogN", PACKAGE = "pcaPP", NAOK = FALSE, DUP = TRUE		##	20130322 set DUP = TRUE - kendallNlogN implementation modifies x & y vectors!!
-				, as.double (x)
-				, as.double (y)
-				, as.integer (c (length (x), cor))
-				, ret = double (1)
-				)
+	ret <- .C (C_kendallNlogN, NAOK = FALSE, DUP = TRUE,		##	20130322 set DUP = TRUE - C_kendallNlogN implementation modifies x & y vectors!!
+				as.double (x),
+				as.double (y),
+				as.integer (c (length (x), cor)),
+				ret = double (1))
 	return (ret$ret)
 }
